#pragma once

//! Identifies various topological shapes. This <br>
//! enumeration allows you to use dynamic typing of shapes. <br>
//! The values are listed in order of complexity, from the <br>
//! most complex to the most simple i.e. <br>
//! COMPOUND > COMPSOLID > SOLID > .... > VERTEX > SHAPE. <br>
//!  Any shape can contain simpler shapes in its definition. <br>
//! Abstract topological data structure describes a basic <br>
//! entity, the shape (present in this enumeration as the <br>
//! SHAPE value), which can be divided into the following <br>
//! component topologies: <br>
//! - COMPOUND: A group of any of the shapes below. <br>
//! - COMPSOLID: A set of solids connected by their <br>
//!   faces. This expands the notions of WIRE and SHELL to solids. <br>
//! - SOLID: A part of 3D space bounded by shells. <br>
//! - SHELL: A set of faces connected by some of the <br>
//!   edges of their wire boundaries. A shell can be open or closed. <br>
//! - FACE: Part of a plane (in 2D geometry) or a surface <br>
//!   (in 3D geometry) bounded by a closed wire. Its <br>
//!   geometry is constrained (trimmed) by contours. <br>
//! - WIRE: A sequence of edges connected by their <br>
//!  vertices. It can be open or closed depending on <br>
//!  whether the edges are linked or not. <br>
//! - EDGE: A single dimensional shape corresponding <br>
//!   to a curve, and bound by a vertex at each extremity. <br>
//! - VERTEX: A zero-dimensional shape corresponding to a point in geometry. <br>
//!	- UNKNOWN: Depending on context either any or an error
typedef enum TopAbs_ShapeEnumKO {

	eShTop_COMPOUND,
	eShTop_COMPSOLID,
	eShTop_SOLID,
	eShTop_SHELL,
	eShTop_FACE,
	eShTop_WIRE,
	eShTop_EDGE,
	eShTop_VERTEX,
	eShTop_SHAPE,
	eShTop_UNKNOWN,

} TopAbs_ShapeEnumKO;

typedef enum GeomAbs_ShapeKO {
	GeomAbs_C0KO,
	GeomAbs_G1KO,
	GeomAbs_C1KO,
	GeomAbs_G2KO,
	GeomAbs_C2KO,
	GeomAbs_C3KO,
	GeomAbs_CNKO
} GeomAbs_ShapeKO;

//! Identifies the orientation of a topological shape. <br>
//! Orientation can represent a relation between two <br>
//! entities, or it can apply to a shape in its own right. <br>
//! When used to describe a relation between two <br>
//! shapes, orientation allows you to use the underlying <br>
//! entity in either direction. For example on a curve <br>
//! which is oriented FORWARD (say from left to right) <br>
//! you can have both a FORWARD and a REVERSED <br>
//! edge. The FORWARD edge will be oriented from <br>
//! left to right, and the REVERSED edge from right to <br>
//! left. In this way, you share the underlying entity. In <br>
//! other words, two faces of a cube can share an <br>
//! edge, and can also be used to build compound shapes. <br>
//! For each case in which an element is used as the <br>
//! boundary of a geometric domain of a higher <br>
//! dimension, this element defines two local regions of <br>
//! which one is arbitrarily considered as the default <br>
//! region. A change in orientation implies a switch of <br>
//! default region. This allows you to apply changes of <br>
//! orientation to the shape as a whole. <br>
typedef enum TopAbs_OrientationKO {
	eOrnTop_FORWARD,
	eOrnTop_REVERSED,
	eOrnTop_INTERNAL,
	eOrnTop_EXTERNAL
} TopAbs_OrientationKO;

//! Identifies the type of a geometric transformation. <br>
typedef enum gp_TrsfFormKO {
	gp_IdentityKO, 
	gp_RotationKO, 
	gp_TranslationKO, 
	gp_PntMirrorKO, 
	gp_Ax1MirrorKO, 
	gp_Ax2MirrorKO, 
	gp_ScaleKO, 
	gp_CompoundTrsfKO, 
	gp_OtherKO, 
} gp_TrsfFormKO;

typedef enum Extrema_ExtFlagKO {
	Extrema_ExtFlag_MINKO,
	Extrema_ExtFlag_MAXKO,
	Extrema_ExtFlag_MINMAXKO,
} Extrema_ExtFlagKO;

typedef enum Extrema_ExtAlgoKO {
	Extrema_ExtAlgo_GradKO,
	Extrema_ExtAlgo_TreeKO,
} Extrema_ExtAlgoKO;

typedef enum BRepExtrema_SupportTypeKO {
	BRepExtrema_IsVertexKO,
	BRepExtrema_IsOnEdgeKO,
	BRepExtrema_IsInFaceKO,
} BRepExtrema_SupportTypeKO;

